@@ -1,7 +1,7 @@
 /* gxmessage - an xmessage clone using GTK2
  *
  * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
- * 2012 Timothy Richard Musson
+ * 2012, 2015 Timothy Richard Musson
  *
  * Email: Tim Musson <trmusson@gmail.com>
  * WWW:   http://homepages.ihug.co.nz/~trmusson/programs.html#gxmessage
@@ -32,7 +32,7 @@
 
 /* Details for Copyright and bug report messages: */
 #define AUTHOR  "Timothy Richard Musson"
-#define YEAR    "2012"
+#define YEAR    "2015"
 #define MAILTO  "<trmusson@gmail.com>"
 
 /* If the following file exists, the -noescape option will be allowed to work: */
@@ -400,7 +400,7 @@ cb_timeout (gint *timeout)
 	return TRUE;
 }
 
-
+#if 0
 gint
 geometry_get_number (const gchar **geometry)
 {
@@ -441,7 +441,7 @@ geometry_parse_string (const gchar *geometry, gint *width, gint *height)
 		if (*height < -1) *height = -1;
 	}
 }
-
+#endif
 
 void
 window_create (void)
@@ -642,7 +642,7 @@ window_create (void)
 		gtk_widget_size_request (btn, &size_req);
 		win_h = win_h + size_req.height + 12;
 	}
-
+#if 0
 	if (gx.geom_str != NULL) {
 		gint tmp_w, tmp_h;
 		geometry_parse_string (gx.geom_str, &tmp_w, &tmp_h);
@@ -652,6 +652,12 @@ window_create (void)
 
 	gtk_window_set_default_size (GTK_WINDOW(window), win_w, win_h);
 	gtk_window_set_position (GTK_WINDOW(window), gx.window_position);
+#endif
+
+	if (gx.geom_str != NULL) {
+		gtk_widget_show_all (vbox); /* must precede parse_geometry */
+		gtk_window_parse_geometry (GTK_WINDOW(window), gx.geom_str);
+	}
 
 	/* open the window */
 	gtk_widget_show_all (window);
